/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package org.apache.hugegraph.structure.auth;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import org.apache.hugegraph.structure.Element;

import java.util.Date;

@JsonInclude(JsonInclude.Include.NON_NULL)
public abstract class AuthElement extends Element {

    public static final String DATE_FORMAT = "yyyy-MM-dd HH:mm:ss.SSS";

    @JsonProperty("id")
    protected Object id;

    @Override
    public Object id() {
        return this.id;
    }

    public void setId(Object id) {
        this.id = id;
    }

    public abstract Date createTime();

    public abstract Date updateTime();

    public abstract String creator();
}
